@@ -7,7 +7,7 @@ from django.contrib.auth.models import (
 from django.contrib.auth.models import Group as BaseGroup
 from django.core.mail import send_mail
 from django.utils import timezone
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 
 class CUserManager(BaseUserManager):
@@ -94,7 +94,7 @@ class AbstractCUser(AbstractBaseUser, PermissionsMixin):
             'unique': _("A user with that email address already exists."),
         },
     )
-    first_name = models.CharField(_('first name'), max_length=30, blank=True)
+    first_name = models.CharField(_('first name'), max_length=150, blank=True)
     last_name = models.CharField(_('last name'), max_length=150, blank=True)
     is_staff = models.BooleanField(
         _('staff status'),
