@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 CUSER_SETTINGS = {
     'app_verbose_name': _("Custom User"),
